pub struct LayerDisplay {
pub levels: HashMap<String, Vec<LayerClient>>,
}Expand description
This struct holds all the layer surfaces for a display
Fields
levels: HashMap<String, Vec<LayerClient>>The different levels of layers
Implementations
Sourceimpl LayerDisplay
impl LayerDisplay
Sourcepub fn iter(&self) -> Iter<'_, String, Vec<LayerClient>>
pub fn iter(&self) -> Iter<'_, String, Vec<LayerClient>>
Creates the iterator of map by references of LayerDisplay
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, String, Vec<LayerClient>>
pub fn iter_mut(&mut self) -> IterMut<'_, String, Vec<LayerClient>>
Creates the iterator of map by mutable references of LayerDisplay.
Sourcepub fn into_keys(self) -> IntoKeys<String, Vec<LayerClient>>
pub fn into_keys(self) -> IntoKeys<String, Vec<LayerClient>>
Creates the consuming iterator by keys with type String of LayerDisplay.
Sourcepub fn into_values(self) -> IntoValues<String, Vec<LayerClient>>
pub fn into_values(self) -> IntoValues<String, Vec<LayerClient>>
Creates the consuming iterator by values of LayerDisplay.