pub struct Workspace {
pub id: WorkspaceId,
pub name: String,
pub monitor: String,
pub monitor_id: Option<MonitorId>,
pub windows: u16,
pub fullscreen: bool,
pub last_window: Address,
pub last_window_title: String,
}Expand description
This struct holds information for a workspace
Fields
id: WorkspaceIdThe workspace Id
name: StringThe workspace’s name
monitor: StringThe monitor the workspace is on
monitor_id: Option<MonitorId>The monitor id the workspace is on, can be None in some cases
windows: u16The amount of windows in the workspace
fullscreen: boolA bool that shows if there is a fullscreen window in the workspace
last_window: AddressThe last window’s Address
last_window_title: StringThe last window’s title