pub enum WorkspaceIdentifier<'a> {
Id(WorkspaceId),
Relative(i32),
RelativeMonitor(i32),
RelativeMonitorIncludingEmpty(i32),
RelativeOpen(i32),
Previous,
Empty,
Name(&'a str),
}Expand description
This enum is for identifying workspaces
Variants
Id(WorkspaceId)
The workspace Id
Relative(i32)
The workspace relative to the current workspace
RelativeMonitor(i32)
The workspace on the monitor relative to the current workspace
RelativeMonitorIncludingEmpty(i32)
The workspace on the monitor relative to the current workspace, including empty workspaces
RelativeOpen(i32)
The open workspace relative to the current workspace
Previous
The previous Workspace
Empty
The first available empty workspace
Name(&'a str)
The name of the workspace