pub struct FirstEmpty {
pub on_monitor: bool,
pub next: bool,
}Expand description
This struct holds options for the first empty workspace
Fields
on_monitor: boolIf the first empty workspace should be on the monitor
next: boolIf the first empty workspace should be next