pub enum HyprError {
SerdeError(Error),
IoError(Error),
InvalidHyprColorFormat,
InvalidHyprGradiantFormat,
FromUtf8Error(FromUtf8Error),
NotOkDispatch(String),
Hyprpaper(Error),
InvalidOptionKey(String),
InvalidOptionValue,
Internal(String),
Other(String),
}Expand description
Error that unifies different error types used by Hyprland-rs
Variants
SerdeError(Error)
Error coming from serde
IoError(Error)
Error coming from std::io
InvalidHyprColorFormat
Error from failing to parse HyprColor
InvalidHyprGradiantFormat
Error from failing to parse HyprGradient
FromUtf8Error(FromUtf8Error)
Error that occurs when parsing UTF-8 string
NotOkDispatch(String)
Dispatcher returned non ok value
Hyprpaper(Error)
Error when interacting with Hyprpaper.
InvalidOptionKey(String)
Keyword does not exist
InvalidOptionValue
Unparsable Option
Internal(String)
Internal Hyprland error
Other(String)
Error that occurs for other reasons. Avoid using this.
Implementations
Sourceimpl HyprError
impl HyprError
Sourcepub fn try_as_cloned(&self) -> Result<Self, &Self>
pub fn try_as_cloned(&self) -> Result<Self, &Self>
Try to get an owned version of the internal error.
Some dependencies of hyprland do not impl Clone in their error types. This is a partial workaround.
If it succeeds, it returns the owned version of HyprError in Ok(). Otherwise, it returns a reference to the error type.