pub struct Address(/* private fields */);Expand description
The address struct holds a address as a tuple with a single value and has methods to reveal the address in different data formats
Implementations