pub struct CommandContent {
pub flag: CommandFlag,
pub data: String,
}Expand description
This struct defines the content of a command, which consists of a flag and a data string.
Fields
flag: CommandFlagThe flag for the command.
data: StringThe data string for the command.
Implementations