pub struct Instance { /* private fields */ }Expand description
This is the sync version of the Hyprland Instance. It holds the event streams connected to the sockets of one running Hyprland instance.
Implementations
Sourceimpl Instance
impl Instance
Sourcepub fn from_current_env() -> Result<Self>
pub fn from_current_env() -> Result<Self>
uses the $HYPRLAND_INSTANCE_SIGNATURE env variable
Sourcepub fn from_instance(name: String) -> Result<Self>
pub fn from_instance(name: String) -> Result<Self>
Uses the name to determine the sockets to use
Example name: 9958d297641b5c84dcff93f9039d80a5ad37ab00_1752788564_214680212
Sourcepub fn from_base_socket_path(path: PathBuf) -> Result<Self>
pub fn from_base_socket_path(path: PathBuf) -> Result<Self>
Uses the path to determine the sockets to use
Example path: /run/user/1000/hypr/9958d297641b5c84dcff93f9039d80a5ad37ab00_1752788564_21468021